Download and import benthic data for Tampa Bay
Details
This function downloads and unzips a folder of base tables used to calculate the benthic index from https://epcbocc.sharepoint.com/:u:/s/PublishedShare/IQDODa-pbW8pTaZMg-93L9sTAZW1Y6hjj1TD_8RY0mFGiQ8?e=9JBNmb&download=1.
Index the corresponding list element in the value column to view each dataset. For example, the stations data in the first row can be viewed as benthicdata$value[[1]].