Map Fecal Indicator Bacteria matrix results by year
Usage
show_fibmatmap(
fibdata,
yrsel,
areasel,
lagyr = 3,
subset_wetdry = c("all", "wet", "dry"),
precipdata = NULL,
temporal_window = NULL,
wet_threshold = NULL,
addsta = FALSE,
listout = FALSE,
warn = TRUE
)Arguments
- fibdata
input data frame as returned by
read_importfib,read_importentero, orread_importwqp, see details- yrsel
numeric value indicating the year to map
- areasel
vector of bay segment or area names to include, see details
- lagyr
numeric for year lag to calculate categories, see details
- subset_wetdry
character, subset data frame to only wet or dry samples as defined by
wet_thresholdandtemporal_window? Defaults to"all", which will not subset. If"wet"or"dry"is specified,anlz_fibwetdryis called using the further specified parameters, and the data frame is subsetted accordingly.- precipdata
input data frame as returned by
read_importrain. columns should be: station, date (yyyy-mm-dd), rain (in inches). The objectcatchpreciphas this data from 1995-2023 for select Enterococcus stations. IfNULL, defaults tocatchprecip.- temporal_window
numeric; required if
subset_wetdryis not"all". number of days precipitation should be summed over (1 = day of sample only; 2 = day of sample + day before; etc.)- wet_threshold
numeric; required if
subset_wetdryis not"all". inches accumulated through the defined temporal window, above which a sample should be defined as being from a 'wet' time period- addsta
logical to add station labels to the map, default
FALSE- listout
logical to return a list of simple feature objects for the data used in the
leafletmap, defaultFALSE- warn
logical to print warnings about stations with insufficient data, default
TRUE
Value
A leaflet map for the selected year and area showing station matrix scores if listout = FALSE (default). Bay segment scores are also shown if the input data are not from EPCHC. A list of simple feature objects is returned if listout = TRUE.
Details
Placing the mouse cursor over an item on the map will reveal additional information about a segment or station.
If the input is from EPCHC (from read_importfib, i.e., fibdata), valid entries for areasel include 'Alafia River', 'Hillsborough River', 'Big Bend', 'Cockroach Bay', 'East Lake Outfall', 'Hillsborough Bay', 'Little Manatee River', 'Lower Tampa Bay', 'McKay Bay', 'Middle Tampa Bay', 'Old Tampa Bay', 'Palm River', 'Tampa Bypass Canal', and 'Valrico Lake'. If the input data is from read_importentero (i.e., enterodata)), valid entries for areasel include 'OTB', 'HB', 'MTB', 'LTB', 'BCB', and 'MR'. If the input is from read_importwqp for Manatee County (21FLMANA_WQX, mancofibdata), Pasco County (21FLPASC_WQX, pascofibdata), Polk County (21FLPOLK_WQX, polcofibdata), or Hillsborough County Environmental Services Division (21FLHESD_WQX, hcesdfibdata) valid entries for areasel are any that are present in the area column for the respective input datasets.
Bay segment matrix categories can be shown if input data are from read_importentero. Stations for these data were chosen specifically as downstream endpoints for each bay segment, whereas the other datasets are not appropriate for estimating bay segment outcomes. Bay segment categories are shown using minor sub-basins. The collection of sub-basins that include stations used to estimate the bay segment outcomes are shown and color-coded by the appropriate outcome for each bay segment.
Care should be taken when communicating results at the bay segment scale to ensure appropriate messaging. Baywide scores could be misleading by using a handful of stations to communicate results at the bay segment scale. Reporting at this scale is meant to support assessments that are comparable to other similar indicators used by TBEP. A low grade for a bay segment does not imply hazardous conditions, rather the score reflects the aggregate likelihood for all stations selected for that bay segment. Remediation of conditions that contribute to fecal contamination is best handled at the site scale.
See also
anlz_fibmatrix for details on the categories
Examples
# non-EPCHC, non Manatee County data
show_fibmatmap(enterodata, yrsel = 2020, areasel = 'OTB')
#> Warning: Stations with insufficient data for lagyr: 21FLHILL_WQX-619, 21FLPDEM_WQX-12-02, 21FLTPA_WQX-G1SW0095
# EPCHC data
show_fibmatmap(fibdata, yrsel = 2016,
areasel = c("Hillsborough River", "Alafia River"))
# Manatee County data
show_fibmatmap(mancofibdata, yrsel = 2020, areasel = 'Manatee River')